@@ -100,7 +100,7 @@ test_that("List formula, names and non-syntactic variables", {
       "|P/E          |               |               |               |",
       "|-  A         |  1 (100.0%)   |  1 (100.0%)   |  2 (100.0%)   |",
       "|% Growth     |               |               |               |",
-      "|-  Mean (SD) |  1.100 (NaN)  |  1.200 (NaN)  | 1.150 (0.071) |",
+      "|-  Mean (SD) |  1.100 (NA)   |  1.200 (NA)   | 1.150 (0.071) |",
       "|-  Range     | 1.100 - 1.100 | 1.200 - 1.200 | 1.100 - 1.200 |",
       ""                                                               ,
       ""                                                               ,
@@ -109,7 +109,7 @@ test_that("List formula, names and non-syntactic variables", {
       "|P/E          |               |               |               |",
       "|-  A         |  1 (100.0%)   |  1 (100.0%)   |  2 (100.0%)   |",
       "|% Growth     |               |               |               |",
-      "|-  Mean (SD) |  1.100 (NaN)  |  1.200 (NaN)  | 1.150 (0.071) |",
+      "|-  Mean (SD) |  1.100 (NA)   |  1.200 (NA)   | 1.150 (0.071) |",
       "|-  Range     | 1.100 - 1.100 | 1.200 - 1.200 | 1.100 - 1.200 |")
   )
 })
