@@ -47,22 +47,118 @@ test_that("strata levels are maintained", {
   tmp$Group[tmp$trt == "A" & tmp$Group == "Low"] <- NA
   expect_identical(
     capture.kable(summary(set_labels(modelsum(Age ~ Sex + dt, adjust = ~ Group, strata = trt, data = tmp), c(GroupLow = "Low")), text = TRUE)),
-    c("|Treatment Arm |            |estimate |std.error |p.value |adj.r.squared |",
-      "|:-------------|:-----------|:--------|:---------|:-------|:-------------|",
-      "|A             |(Intercept) |42.139   |2.047     |< 0.001 |-0.047        |",
-      "|              |Sex Male    |-2.277   |2.456     |0.364   |              |",
-      "|              |Group Med   |-0.533   |2.472     |0.831   |              |",
-      "|              |(Intercept) |34.850   |3.600     |< 0.001 |0.065         |",
-      "|              |dt          |-0.001   |0.000     |0.072   |              |",
-      "|              |Group Med   |-1.642   |2.394     |0.500   |              |",
-      "|B             |(Intercept) |38.733   |1.470     |< 0.001 |-0.050        |",
-      "|              |Sex Male    |0.908    |1.407     |0.522   |              |",
-      "|              |Low         |0.205    |1.753     |0.907   |              |",
-      "|              |Group Med   |-0.317   |1.753     |0.857   |              |",
-      "|              |(Intercept) |47.149   |2.812     |< 0.001 |0.114         |",
-      "|              |dt          |0.001    |0.000     |0.003   |              |",
-      "|              |Low         |-0.145   |1.613     |0.929   |              |",
-      "|              |Group Med   |-0.318   |1.610     |0.844   |              |"
+    c("|Treatment Arm |            |estimate |std.error |p.value |adj.r.squared |Nmiss |",
+      "|:-------------|:-----------|:--------|:---------|:-------|:-------------|:-----|",
+      "|A             |(Intercept) |42.139   |2.047     |< 0.001 |-0.047        |11    |",
+      "|              |Sex Male    |-2.277   |2.456     |0.364   |              |      |",
+      "|              |Group Med   |-0.533   |2.472     |0.831   |              |      |",
+      "|              |(Intercept) |34.850   |3.600     |< 0.001 |0.065         |11    |",
+      "|              |dt          |-0.001   |0.000     |0.072   |              |      |",
+      "|              |Group Med   |-1.642   |2.394     |0.500   |              |      |",
+      "|B             |(Intercept) |38.733   |1.470     |< 0.001 |-0.050        |0     |",
+      "|              |Sex Male    |0.908    |1.407     |0.522   |              |      |",
+      "|              |Low         |0.205    |1.753     |0.907   |              |      |",
+      "|              |Group Med   |-0.317   |1.753     |0.857   |              |      |",
+      "|              |(Intercept) |47.149   |2.812     |< 0.001 |0.114         |0     |",
+      "|              |dt          |0.001    |0.000     |0.003   |              |      |",
+      "|              |Low         |-0.145   |1.613     |0.929   |              |      |",
+      "|              |Group Med   |-0.318   |1.610     |0.844   |              |      |"
+    )
+  )
+})
+
+test_that("Multiple adjustments work (#240)", {
+  tmp.ms <- modelsum(list(age, bmi) ~ fu.time + ast, adjust = list(Unadjusted = ~ 1, "Adjusted for Arm" = ~ arm, "HGB + PS" = ~ hgb + ps),
+                     data = set_labels(mockstudy, list(ast = "AST", ps = "PS")), strata = sex,
+                     gaussian.stats = c("estimate", "std.error", "p.value", "adj.r.squared", "Nmiss", "N"))
+  expect_identical(
+    capture.kable(summary(tmp.ms, adjustment.names = TRUE, term.name = TRUE)),
+    c("|sex    |adjustment       |Age in Years                |estimate |std.error |p.value |adj.r.squared |Nmiss |N   |",
+      "|:------|:----------------|:---------------------------|:--------|:---------|:-------|:-------------|:-----|:---|",
+      "|Male   |Unadjusted       |(Intercept)                 |61.686   |0.654     |< 0.001 |0.005         |0     |916 |",
+      "|       |                 |**fu.time**                 |-0.002   |0.001     |0.022   |              |      |    |",
+      "|       |Adjusted for Arm |(Intercept)                 |61.073   |0.837     |< 0.001 |0.004         |0     |916 |",
+      "|       |                 |**fu.time**                 |-0.002   |0.001     |0.016   |              |      |    |",
+      "|       |                 |**Treatment Arm F: FOLFOX** |1.048    |0.889     |0.239   |              |      |    |",
+      "|       |                 |**Treatment Arm G: IROX**   |0.857    |1.015     |0.399   |              |      |    |",
+      "|       |HGB + PS         |(Intercept)                 |57.090   |3.068     |< 0.001 |0.010         |162   |754 |",
+      "|       |                 |**fu.time**                 |-0.002   |0.001     |0.008   |              |      |    |",
+      "|       |                 |**hgb**                     |0.365    |0.234     |0.118   |              |      |    |",
+      "|       |                 |**PS**                      |0.881    |0.746     |0.238   |              |      |    |",
+      "|       |Unadjusted       |(Intercept)                 |61.556   |0.696     |< 0.001 |0.003         |162   |754 |",
+      "|       |                 |**AST**                     |-0.028   |0.016     |0.074   |              |      |    |",
+      "|       |Adjusted for Arm |(Intercept)                 |61.524   |0.947     |< 0.001 |0.001         |162   |754 |",
+      "|       |                 |**AST**                     |-0.028   |0.016     |0.075   |              |      |    |",
+      "|       |                 |**Treatment Arm F: FOLFOX** |0.322    |0.977     |0.741   |              |      |    |",
+      "|       |                 |**Treatment Arm G: IROX**   |-0.445   |1.115     |0.690   |              |      |    |",
+      "|       |HGB + PS         |(Intercept)                 |57.707   |3.133     |< 0.001 |0.006         |162   |754 |",
+      "|       |                 |**AST**                     |-0.032   |0.016     |0.043   |              |      |    |",
+      "|       |                 |**hgb**                     |0.253    |0.232     |0.276   |              |      |    |",
+      "|       |                 |**PS**                      |1.529    |0.739     |0.039   |              |      |    |",
+      "|Female |Unadjusted       |(Intercept)                 |59.385   |0.822     |< 0.001 |-0.002        |0     |583 |",
+      "|       |                 |**fu.time**                 |-0.000   |0.001     |0.835   |              |      |    |",
+      "|       |Adjusted for Arm |(Intercept)                 |59.449   |1.089     |< 0.001 |-0.003        |0     |583 |",
+      "|       |                 |**fu.time**                 |-0.000   |0.001     |0.707   |              |      |    |",
+      "|       |                 |**Treatment Arm F: FOLFOX** |0.580    |1.216     |0.634   |              |      |    |",
+      "|       |                 |**Treatment Arm G: IROX**   |-0.856   |1.353     |0.527   |              |      |    |",
+      "|       |HGB + PS         |(Intercept)                 |46.660   |4.632     |< 0.001 |0.015         |104   |479 |",
+      "|       |                 |**fu.time**                 |-0.001   |0.001     |0.564   |              |      |    |",
+      "|       |                 |**hgb**                     |1.156    |0.378     |0.002   |              |      |    |",
+      "|       |                 |**PS**                      |-0.421   |0.902     |0.641   |              |      |    |",
+      "|       |Unadjusted       |(Intercept)                 |61.001   |0.883     |< 0.001 |0.004         |104   |479 |",
+      "|       |                 |**AST**                     |-0.033   |0.020     |0.096   |              |      |    |",
+      "|       |Adjusted for Arm |(Intercept)                 |60.687   |1.266     |< 0.001 |0.006         |104   |479 |",
+      "|       |                 |**AST**                     |-0.032   |0.020     |0.102   |              |      |    |",
+      "|       |                 |**Treatment Arm F: FOLFOX** |1.253    |1.297     |0.334   |              |      |    |",
+      "|       |                 |**Treatment Arm G: IROX**   |-1.006   |1.441     |0.486   |              |      |    |",
+      "|       |HGB + PS         |(Intercept)                 |47.825   |4.730     |< 0.001 |0.017         |104   |479 |",
+      "|       |                 |**AST**                     |-0.026   |0.020     |0.193   |              |      |    |",
+      "|       |                 |**hgb**                     |1.086    |0.376     |0.004   |              |      |    |",
+      "|       |                 |**PS**                      |-0.115   |0.873     |0.895   |              |      |    |",
+      ""                                                                                                                 ,
+      ""                                                                                                                 ,
+      "|sex    |adjustment       |Body Mass Index (kg/m^2)    |estimate |std.error |p.value |adj.r.squared |Nmiss |N   |",
+      "|:------|:----------------|:---------------------------|:--------|:---------|:-------|:-------------|:-----|:---|",
+      "|Male   |Unadjusted       |(Intercept)                 |26.679   |0.294     |< 0.001 |0.011         |22    |894 |",
+      "|       |                 |**fu.time**                 |0.001    |0.000     |< 0.001 |              |      |    |",
+      "|       |Adjusted for Arm |(Intercept)                 |26.901   |0.376     |< 0.001 |0.012         |22    |894 |",
+      "|       |                 |**fu.time**                 |0.001    |0.000     |< 0.001 |              |      |    |",
+      "|       |                 |**Treatment Arm F: FOLFOX** |-0.594   |0.397     |0.134   |              |      |    |",
+      "|       |                 |**Treatment Arm G: IROX**   |-0.040   |0.451     |0.930   |              |      |    |",
+      "|       |HGB + PS         |(Intercept)                 |23.559   |1.321     |< 0.001 |0.036         |181   |735 |",
+      "|       |                 |**fu.time**                 |0.001    |0.000     |0.021   |              |      |    |",
+      "|       |                 |**hgb**                     |0.283    |0.101     |0.005   |              |      |    |",
+      "|       |                 |**PS**                      |-0.794   |0.322     |0.014   |              |      |    |",
+      "|       |Unadjusted       |(Intercept)                 |27.885   |0.306     |< 0.001 |0.006         |181   |735 |",
+      "|       |                 |**AST**                     |-0.016   |0.007     |0.023   |              |      |    |",
+      "|       |Adjusted for Arm |(Intercept)                 |28.040   |0.412     |< 0.001 |0.004         |181   |735 |",
+      "|       |                 |**AST**                     |-0.016   |0.007     |0.023   |              |      |    |",
+      "|       |                 |**Treatment Arm F: FOLFOX** |-0.354   |0.427     |0.408   |              |      |    |",
+      "|       |                 |**Treatment Arm G: IROX**   |0.015    |0.486     |0.976   |              |      |    |",
+      "|       |HGB + PS         |(Intercept)                 |24.297   |1.350     |< 0.001 |0.032         |181   |735 |",
+      "|       |                 |**AST**                     |-0.011   |0.007     |0.123   |              |      |    |",
+      "|       |                 |**hgb**                     |0.307    |0.100     |0.002   |              |      |    |",
+      "|       |                 |**PS**                      |-0.878   |0.318     |0.006   |              |      |    |",
+      "|Female |Unadjusted       |(Intercept)                 |26.198   |0.423     |< 0.001 |0.003         |11    |572 |",
+      "|       |                 |**fu.time**                 |0.001    |0.001     |0.101   |              |      |    |",
+      "|       |Adjusted for Arm |(Intercept)                 |26.198   |0.560     |< 0.001 |0.002         |11    |572 |",
+      "|       |                 |**fu.time**                 |0.001    |0.001     |0.164   |              |      |    |",
+      "|       |                 |**Treatment Arm F: FOLFOX** |0.366    |0.625     |0.558   |              |      |    |",
+      "|       |                 |**Treatment Arm G: IROX**   |-0.386   |0.692     |0.577   |              |      |    |",
+      "|       |HGB + PS         |(Intercept)                 |27.620   |2.409     |< 0.001 |-0.000        |113   |470 |",
+      "|       |                 |**fu.time**                 |0.001    |0.001     |0.099   |              |      |    |",
+      "|       |                 |**hgb**                     |-0.121   |0.196     |0.539   |              |      |    |",
+      "|       |                 |**PS**                      |0.184    |0.467     |0.694   |              |      |    |",
+      "|       |Unadjusted       |(Intercept)                 |26.500   |0.456     |< 0.001 |0.001         |113   |470 |",
+      "|       |                 |**AST**                     |0.012    |0.010     |0.247   |              |      |    |",
+      "|       |Adjusted for Arm |(Intercept)                 |26.062   |0.649     |< 0.001 |0.008         |113   |470 |",
+      "|       |                 |**AST**                     |0.012    |0.010     |0.225   |              |      |    |",
+      "|       |                 |**Treatment Arm F: FOLFOX** |1.102    |0.669     |0.100   |              |      |    |",
+      "|       |                 |**Treatment Arm G: IROX**   |-0.276   |0.741     |0.710   |              |      |    |",
+      "|       |HGB + PS         |(Intercept)                 |27.324   |2.462     |< 0.001 |-0.003        |113   |470 |",
+      "|       |                 |**AST**                     |0.012    |0.010     |0.255   |              |      |    |",
+      "|       |                 |**hgb**                     |-0.064   |0.196     |0.743   |              |      |    |",
+      "|       |                 |**PS**                      |-0.103   |0.454     |0.821   |              |      |    |"
     )
   )
 })
@@ -263,7 +359,7 @@ test_that("Changing labels", {
 })
 
 ###########################################################################################################
-#### Reported bugs for tableby
+#### Reported bugs for modelsum
 ###########################################################################################################
 
 test_that("02/23/2018: wrapping long labels (#59)", {
