@@ -137,6 +137,28 @@ test_that("Writing HTML from PDF works (#162)", {
   ), reference = "write2.render.html.Rmd")
 })
 
+test_that("verbatim(call()) works (#248)", {
+  expect_identical(
+    capture.output(print(verbatim(call("hi", x = 1), NULL, "hi"))),
+    c("```"       ,
+      "hi(x = 1)" ,
+      ""          ,
+      "```"       ,
+      ""          ,
+      "```"       ,
+      "NULL"      ,
+      ""          ,
+      "```"       ,
+      ""          ,
+      "```"       ,
+      "[1] \"hi\"",
+      ""          ,
+      "```"       ,
+      ""
+    )
+  )
+})
+
 ###########################################################################################################
 #### YAML output
 ###########################################################################################################
